##  Previewing and Starting a Presentation
You can preview a presentation and then start it in full-screen presenter mode.
  * Preview mode: To preview a presentation, click Preview in the upper-right corner of the presentation. To exit the preview mode, click Close.
  * Full-screen mode: To start a presentation in full-screen presenter mode, click Preview, then click the full-screen mode icon ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742f3e37a441014a2baffbfe2da9bb2_LowRes.png) at the bottom of the presentation. To go back to the preview mode, click the full-screen mode icon ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742f3e37a441014a2baffbfe2da9bb2_LowRes.png) once again or press Esc.


You can navigate between the slides by:
  * Using the Right Arrow and Left Arrow keyboard keys
  * Clicking the arrow icons at the bottom of the presentation


![Previewing a Presentation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274805227a44101488a3ff4af23a34cf_LowRes.gif)
Previewing a Presentation
